Package: tatoo
Type: Package
Title: Combine and Export Data Frames
Version: 1.1.2
Authors@R: person("Stefan", "Fleck", email = "stefan.b.fleck@gmail.com", role = c("aut", "cre"))
Maintainer: Stefan Fleck <stefan.b.fleck@gmail.com>
Description: 
  Functions to combine data.frames in ways that require additional effort in 
  base R, and to add metadata (id, title, ...) that can be used for printing and 
  xlsx export. The 'Tatoo_report' class is provided as a 
  convenient helper to write several such tables to a workbook, one table per 
  worksheet. Tatoo is built on top of 'openxlsx', but intimate knowledge of 
  that package is not required to use tatoo.
License: MIT + file LICENSE
Imports: assertthat, magrittr, data.table, openxlsx (>= 4.0.0),
        stringi, colt, crayon, withr
Suggests: testthat, rprojroot, kableExtra, knitr, rmarkdown
RoxygenNote: 7.2.3
Encoding: UTF-8
VignetteBuilder: knitr
BugReports: https://github.com/statistikat/tatoo/issues
URL: https://github.com/statistikat/tatoo
NeedsCompilation: no
Packaged: 2023-03-26 09:18:23 UTC; stefan.fleck
Author: Stefan Fleck [aut, cre]
Repository: CRAN
Date/Publication: 2023-03-26 09:50:02 UTC
Built: R 4.4.0; ; 2024-05-01 08:10:49 UTC; unix
