# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,Composite_table)
S3method(as.data.frame,Mashed_table)
S3method(as.data.table,Composite_table)
S3method(as.data.table,Mashed_table)
S3method(as_Composite_table,Mashed_table)
S3method(as_Composite_table,data.frame)
S3method(as_Composite_table,data.table)
S3method(as_latex,Composite_table)
S3method(as_latex,Mashed_table)
S3method(as_latex,Tagged_table)
S3method(as_latex,Tatoo_report)
S3method(as_latex,data.frame)
S3method(as_latex,list)
S3method(as_lines,Composite_table)
S3method(as_lines,Mashed_table)
S3method(as_lines,Stacked_table)
S3method(as_lines,TT_meta)
S3method(as_lines,Tagged_table)
S3method(as_lines,Tatoo_report)
S3method(as_lines,data.frame)
S3method(as_workbook,Tatoo_report)
S3method(as_workbook,Workbook)
S3method(as_workbook,default)
S3method(flip_names,Composite_table)
S3method(is_valid,Mashed_table)
S3method(is_valid,Stacked_table)
S3method(is_valid,TT_meta)
S3method(is_valid,Tatoo_report)
S3method(print,Composite_table)
S3method(print,Mashed_table)
S3method(print,Stacked_table)
S3method(print,TT_meta)
S3method(print,Tagged_table)
S3method(print,Tatoo_report)
S3method(regions,Workbook)
S3method(regions,character)
S3method(save_pdf,default)
S3method(save_xlsx,default)
S3method(write_worksheet,Composite_table)
S3method(write_worksheet,Mashed_table)
S3method(write_worksheet,Stacked_table)
S3method(write_worksheet,Tagged_table)
S3method(write_worksheet,default)
export("footer<-")
export("id_vars<-")
export("insert_blank_row<-")
export("longtitle<-")
export("mash_method<-")
export("meta<-")
export("multinames<-")
export("sep_height<-")
export("spacing<-")
export("subtitle<-")
export("table_id<-")
export("title<-")
export(as_Composite_table)
export(as_Mashed_table)
export(as_latex)
export(as_lines)
export(as_multinames)
export(as_workbook)
export(cmash)
export(comp_table)
export(comp_table_list)
export(compile_report)
export(compile_report_list)
export(default_kable_options)
export(flip_names)
export(is_Composite_table)
export(is_Mashed_table)
export(is_Stacked_table)
export(is_Tagged_table)
export(is_Tatoo_report)
export(is_Tatoo_table)
export(mash_table)
export(mash_table_list)
export(meta)
export(multinames)
export(multinames_to_colspans)
export(open_file)
export(regions)
export(rmash)
export(sanitize_excel_sheet_names)
export(save_pdf)
export(save_xlsx)
export(stack_table)
export(stack_table_list)
export(table_id)
export(tag_table)
export(tt_meta)
export(view_pdf)
export(view_xlsx)
export(walk_regions)
export(write_worksheet)
import(assertthat)
importFrom(data.table,as.data.table)
importFrom(data.table,data.table)
importFrom(magrittr,"%>%")
